.. coffea documentation master file, created by
   sphinx-quickstart on Fri Jun  7 09:23:02 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

.. toctree::
   quick_start
   introduction
   reference
..

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
